import setuptools
setuptools.setup(name='ocfl_rehydration',
version='0.2',
description='Tooling for rehydrating an original DRS object from its OCFL form',
url='https://github.com/harvard-lts/ocfl_rehydration',
author='Andrew Woods',
install_requires=[''],
author_email='andrew_woods@harvard.edu',
packages=['ocfl_rehydration'], 
zip_safe=False)
